<!-- markdownlint-disable MD022 -->

# Changelog

(v0.3.0)=
## 0.3.0 - 2025-08-16

-   Disable pytest cache for Debian pybuild
    ([!10](https://git.ligo.org/computing/software/igwn-robot-auth/-/merge_requests/10))

-   Improve documentation for condor users
    ([!12](https://git.ligo.org/computing/software/igwn-robot-auth/-/merge_requests/12))

-   Make htcondor an optional requirement for pip installs
    ([!13](https://git.ligo.org/computing/software/igwn-robot-auth/-/merge_requests/13))

-   Add 'force' option to configure_logging
    ([!14](https://git.ligo.org/computing/software/igwn-robot-auth/-/merge_requests/14))

-   Depend explicitly on igwn-auth-utils extras
    ([!15](https://git.ligo.org/computing/software/igwn-robot-auth/-/merge_requests/15))

-   Allow not passing a principal name
    ([!16](https://git.ligo.org/computing/software/igwn-robot-auth/-/merge_requests/16))

-   Add Dockerfile and containerisation documentation
    ([!17](https://git.ligo.org/computing/software/igwn-robot-auth/-/merge_requests/17))

(v0.2.0)=
## 0.2.0 - 2025-04-30

-   Add support for minsecs in igwn-robot-get
    ([!8](https://git.ligo.org/computing/software/igwn-robot-auth/-/merge_requests/8))

[Full details](https://git.ligo.org/computing/software/igwn-robot-auth/-/releases/0.2.0)

(v0.1.0)=
## 0.1.0 - 2025-04-02

- First release

[Full details](https://git.ligo.org/computing/software/igwn-robot-auth/-/releases/0.1.0)
